@@ -34,11 +34,12 @@ except Exception as e:
     LastFM = None
 
 from lollypop.utils import is_gnome, is_unity
-from lollypop.define import Lp, ArtSize
+from lollypop.define import ArtSize
 from lollypop.window import Window
 from lollypop.database import Database
 from lollypop.player import Player
 from lollypop.art import Art
+from lollypop.sqlcursor import SqlCursor
 from lollypop.settings import Settings, SettingsDialog
 from lollypop.mpris import MPRIS
 from lollypop.notification import NotificationManager
@@ -50,6 +51,7 @@ from lollypop.playlists import Playlists
 from lollypop.radios import Radios
 from lollypop.collectionscanner import CollectionScanner
 from lollypop.fullscreen import FullScreen
+from lollypop.mpd import MpdServerDaemon
 
 
 class Application(Gtk.Application):
@@ -68,6 +70,13 @@ class Application(Gtk.Application):
                             self,
                             application_id='org.gnome.Lollypop',
                             flags=Gio.ApplicationFlags.HANDLES_COMMAND_LINE)
+        self.cursors = {}
+        self.window = None
+        self.notify = None
+        self.mpd = None
+        self.lastfm = None
+        self.debug = False
+        self._externals_count = 0
         self._init_proxy()
         GLib.set_application_name('lollypop')
         GLib.set_prgname('lollypop')
@@ -78,56 +87,67 @@ class Application(Gtk.Application):
             self.add_main_option("set-rating", b'r', GLib.OptionFlags.NONE,
                                  GLib.OptionArg.INT, "Rate the current track",
                                  None)
-        self.connect('handle-local-options', self._on_handle_local_options)
+            self.add_main_option("play-pause", b't', GLib.OptionFlags.NONE,
+                                 GLib.OptionArg.NONE, "Toggle playback",
+                                 None)
+            self.add_main_option("next", b'n', GLib.OptionFlags.NONE,
+                                 GLib.OptionArg.NONE, "Go to next track",
+                                 None)
+            self.add_main_option("prev", b'p', GLib.OptionFlags.NONE,
+                                 GLib.OptionArg.NONE, "Go to prev track",
+                                 None)
         self.connect('command-line', self._on_command_line)
+        self.register(None)
+        if self.get_is_remote():
+            Gdk.notify_startup_complete()
+
+    def init(self):
+        """
+            Init main application
+        """
         cssProviderFile = Gio.File.new_for_uri(
             'resource:///org/gnome/Lollypop/application.css')
         cssProvider = Gtk.CssProvider()
         cssProvider.load_from_file(cssProviderFile)
         screen = Gdk.Screen.get_default()
-        monitor = screen.get_primary_monitor()
-        geometry = screen.get_monitor_geometry(monitor)
-        # We want 500 and 200 in full hd
-        # Do not upscale on HiDPI
-        ArtSize.BIG = int(200*geometry.width/1920)
-        ArtSize.MONSTER = int(500*geometry.width/1920)
-
         styleContext = Gtk.StyleContext()
         styleContext.add_provider_for_screen(screen, cssProvider,
                                              Gtk.STYLE_PROVIDER_PRIORITY_USER)
-        Lp.settings = Settings.new()
+        self.settings = Settings.new()
+        ArtSize.BIG = self.settings.get_value('cover-size').get_int32()
         if LastFM is not None:
-            Lp.lastfm = LastFM()
-        Lp.db = Database()
-        # We store a cursor for the main thread
-        Lp.sql = Lp.db.get_cursor()
-        Lp.albums = AlbumsDatabase()
-        Lp.artists = ArtistsDatabase()
-        Lp.genres = GenresDatabase()
-        Lp.tracks = TracksDatabase()
-        Lp.player = Player()
-        Lp.playlists = Playlists()
-        Lp.scanner = CollectionScanner()
-        Lp.art = Art()
-        if not Lp.settings.get_value('disable-mpris'):
+            self.lastfm = LastFM()
+        self.db = Database()
+        self.playlists = Playlists()
+        # We store cursors for main thread
+        SqlCursor.add(self.db)
+        SqlCursor.add(self.playlists)
+        self.albums = AlbumsDatabase()
+        self.artists = ArtistsDatabase()
+        self.genres = GenresDatabase()
+        self.tracks = TracksDatabase()
+        self.player = Player()
+        self.scanner = CollectionScanner()
+        self.art = Art()
+        if not self.settings.get_value('disable-mpris'):
             MPRIS(self)
-        if not Lp.settings.get_value('disable-notifications'):
-            Lp.notify = NotificationManager()
+        if not self.settings.get_value('disable-mpd'):
+            self.mpd = MpdServerDaemon(
+                               self.settings.get_value('mpd-eth').get_string(),
+                               self.settings.get_value('mpd-port').get_int32())
+        if not self.settings.get_value('disable-notifications'):
+            self.notify = NotificationManager()
 
         settings = Gtk.Settings.get_default()
-        dark = Lp.settings.get_value('dark-ui')
+        dark = self.settings.get_value('dark-ui')
         settings.set_property('gtk-application-prefer-dark-theme', dark)
 
         self._parser = TotemPlParser.Parser.new()
         self._parser.connect('entry-parsed', self._on_entry_parsed)
 
-        self.add_action(Lp.settings.create_action('shuffle'))
-        self._externals_count = 0
-        self._is_fs = False
+        self.add_action(self.settings.create_action('shuffle'))
 
-        self.register(None)
-        if self.get_is_remote():
-            Gdk.notify_startup_complete()
+        self._is_fs = False
 
     def do_startup(self):
         """
@@ -142,61 +162,61 @@ class Application(Gtk.Application):
         if encoding is None or encoding != "UTF-8":
             builder = Gtk.Builder()
             builder.add_from_resource('/org/gnome/Lollypop/Unicode.ui')
-            Lp.window = builder.get_object('unicode')
-            Lp.window.set_application(self)
-            Lp.window.show()
-        elif not Lp.window:
+            self.window = builder.get_object('unicode')
+            self.window.set_application(self)
+            self.window.show()
+        elif not self.window:
+            self.init()
             menu = self._setup_app_menu()
             # If GNOME/Unity, add appmenu
             if is_gnome() or is_unity():
                 self.set_app_menu(menu)
-            Lp.window = Window(self)
+            self.window = Window(self)
             # If not GNOME add menu to toolbar
             if not is_gnome() and not is_unity():
-                Lp.window.setup_menu(menu)
-            Lp.window.connect('delete-event', self._hide_on_delete)
-            Lp.window.init_list_one()
-            Lp.window.show()
-            Lp.player.restore_state()
+                self.window.setup_menu(menu)
+            self.window.connect('delete-event', self._hide_on_delete)
+            self.window.init_list_one()
+            self.window.show()
+            self.player.restore_state()
 
     def prepare_to_exit(self, action=None, param=None):
         """
             Save window position and view
         """
-        if Lp.settings.get_value('save-state'):
-            Lp.window.save_view_state()
-            if Lp.player.current_track.id is None:
+        if self.settings.get_value('save-state'):
+            self.window.save_view_state()
+            if self.player.current_track.id is None:
                 track_id = -1
             else:
-                track_id = Lp.player.current_track.id
-            Lp.settings.set_value('track-id', GLib.Variant('i',
-                                                           track_id))
-        Lp.player.stop()
-        if Lp.window:
-            Lp.window.stop_all()
+                track_id = self.player.current_track.id
+            self.settings.set_value('track-id', GLib.Variant('i',
+                                                             track_id))
+        self.player.stop()
+        if self.window:
+            self.window.stop_all()
         self.quit()
 
     def quit(self):
         """
             Quit lollypop
         """
-        if Lp.scanner.is_locked():
-            Lp.scanner.stop()
+        if self.mpd is not None:
+            self.mpd.quit()
+        if self.scanner.is_locked():
+            self.scanner.stop()
             GLib.idle_add(self.quit)
             return
         try:
-            Lp.sql.execute('VACUUM')
-            sql_p = Lp.playlists.get_cursor()
-            sql_p.execute('VACUUM')
-            sql_p.close()
-            radios = Radios()
-            sql_r = radios.get_cursor()
-            sql_r.execute('VACUUM')
-            sql_r.close()
+            with SqlCursor(self.db) as sql:
+                sql.execute('VACUUM')
+            with SqlCursor(self.playlists) as sql:
+                sql.execute('VACUUM')
+            with SqlCursor(Radios()) as sql:
+                sql.execute('VACUUM')
         except Exception as e:
             print("Application::quit(): ", e)
-        Lp.window.destroy()
-        Lp.sql.close()
+        self.window.destroy()
         Gst.deinit()
 
     def is_fullscreen(self):
@@ -221,16 +241,6 @@ class Application(Gtk.Application):
         except:
             pass
 
-    def _on_handle_local_options(self, app, options):
-        """
-            Handle command line
-            @param app as Gio.Application
-            @param options as GLib.VariantDict
-        """
-        if options.contains('debug'):
-            Lp.debug = True
-        return -1
-
     def _on_command_line(self, app, app_cmd_line):
         """
             Handle command line
@@ -239,14 +249,22 @@ class Application(Gtk.Application):
         """
         self._externals_count = 0
         options = app_cmd_line.get_options_dict()
+        if options.contains('debug'):
+            self.debug = True
         if options.contains('set-rating'):
             value = options.lookup_value('set-rating').get_int32()
             if value > 0 and value < 6 and\
-                    Lp.player.current_track.id is not None:
-                Lp.player.current_track.set_popularity(value)
+                    self.player.current_track.id is not None:
+                self.player.current_track.set_popularity(value)
+        if options.contains('play-pause'):
+            self.player.play_pause()
+        elif options.contains('next'):
+            self.player.next()
+        elif options.contains('prev'):
+            self.player.prev()
         args = app_cmd_line.get_arguments()
         if len(args) > 1:
-            Lp.player.clear_externals()
+            self.player.clear_externals()
             for f in args[1:]:
                 try:
                     f = GLib.filename_to_uri(f)
@@ -254,8 +272,9 @@ class Application(Gtk.Application):
                     pass
                 self._parser.parse_async(f, True,
                                          None, None)
-        if Lp.window is not None:
-            Lp.window.present()
+        if self.window is not None and not self.window.is_visible():
+            self.window.setup_window()
+            self.window.present()
         return 0
 
     def _on_entry_parsed(self, parser, uri, metadata):
@@ -265,10 +284,10 @@ class Application(Gtk.Application):
             @param track uri as str
             @param metadata as GLib.HastTable
         """
-        Lp.player.load_external(uri)
+        self.player.load_external(uri)
         if self._externals_count == 0:
-            Lp.player.set_party(False)
-            Lp.player.play_first_external()
+            self.player.set_party(False)
+            self.player.play_first_external()
         self._externals_count += 1
 
     def _hide_on_delete(self, widget, event):
@@ -277,9 +296,9 @@ class Application(Gtk.Application):
             @param widget as Gtk.Widget
             @param event as Gdk.Event
         """
-        if not Lp.settings.get_value('background-mode'):
+        if not self.settings.get_value('background-mode'):
             GLib.timeout_add(500, self.prepare_to_exit)
-            Lp.scanner.stop()
+            self.scanner.stop()
         return widget.hide_on_delete()
 
     def _update_db(self, action=None, param=None):
@@ -288,11 +307,11 @@ class Application(Gtk.Application):
             @param action as Gio.SimpleAction
             @param param as GLib.Variant
         """
-        if Lp.window:
-            t = Thread(target=Lp.art.clean_all_cache)
+        if self.window:
+            t = Thread(target=self.art.clean_all_cache)
             t.daemon = True
             t.start()
-            Lp.window.update_db()
+            self.window.update_db()
 
     def _fullscreen(self, action=None, param=None):
         """
@@ -300,8 +319,8 @@ class Application(Gtk.Application):
             @param action as Gio.SimpleAction
             @param param as GLib.Variant
         """
-        if Lp.window and not self._is_fs:
-            fs = FullScreen(self, Lp.window)
+        if self.window and not self._is_fs:
+            fs = FullScreen(self, self.window)
             fs.connect("destroy", self._on_fs_destroyed)
             self._is_fs = True
             fs.show()
@@ -330,8 +349,14 @@ class Application(Gtk.Application):
         """
         builder = Gtk.Builder()
         builder.add_from_resource('/org/gnome/Lollypop/AboutDialog.ui')
+        builder.get_object('artists').set_text(_("%s artist(s)") %
+                                               self.artists.count())
+        builder.get_object('albums').set_text(_("%s album(s)") %
+                                              self.albums.count())
+        builder.get_object('tracks').set_text(_("%s track(s)") %
+                                              self.tracks.count())
         about = builder.get_object('about_dialog')
-        about.set_transient_for(Lp.window)
+        about.set_transient_for(self.window)
         about.connect("response", self._about_response)
         about.show()
 
@@ -384,6 +409,7 @@ class Application(Gtk.Application):
 
         aboutAction = Gio.SimpleAction.new('about', None)
         aboutAction.connect('activate', self._about)
+        self.set_accels_for_action('app.about', ["F2"])
         self.add_action(aboutAction)
 
         helpAction = Gio.SimpleAction.new('help', None)
