@@ -36,7 +36,7 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
         BaseArt.__init__(self)
         ArtDownloader.__init__(self)
         TagReader.__init__(self)
-        self._favorite = Lp.settings.get_value('favorite-cover').get_string()
+        self._favorite = Lp().settings.get_value('favorite-cover').get_string()
 
     def get_album_cache_path(self, album, size):
         """
@@ -65,7 +65,7 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
             print("Art::get_album_cache_path(): %s" % e, ascii(filename))
             return None
 
-    def get_album_artwork_path(self, album, sql=None):
+    def get_album_artwork_path(self, album):
         """
             Look for artwork in dir:
             - favorite from settings first
@@ -192,16 +192,15 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
         else:
             return self._get_default_icon(size, 'folder-music-symbolic')
 
-    def save_album_artwork(self, pixbuf, album_id, sql=None):
+    def save_album_artwork(self, pixbuf, album_id):
         """
             Save pixbuf for album id
             @param pixbuf as Gdk.Pixbuf
             @param album id as int
-            @param sql as sqlite cursor
         """
         try:
             album = Album(album_id)
-            path_count = Lp.albums.get_path_count(album.path, sql)
+            path_count = Lp().albums.get_path_count(album.path)
             # Many albums with same path, suffix with artist_album name
             if path_count > 1:
                 artpath = os.path.join(album.path, "{}_{}.jpg".format(
@@ -221,13 +220,12 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
         """
         self.emit('album-artwork-changed', album_id)
 
-    def clean_album_cache(self, album, sql=None):
+    def clean_album_cache(self, album):
         """
             Remove cover from cache for album id
             @param album as Album
-            @param sql as sqlite cursor
         """
-        filename = self._get_album_cache_name(album, sql)
+        filename = self._get_album_cache_name(album)
         try:
             for f in os.listdir(self._CACHE_PATH):
                 if re.search('%s_.*\.jpg' % re.escape(filename), f):
@@ -242,33 +240,32 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
             @param size as int
         """
         pixbuf = None
-        infos = self.get_infos(filepath)
-        exist = False
-        if infos is not None:
-            (exist, sample) = infos.get_tags().get_sample_index('image', 0)
-        if exist:
-            (exist, mapflags) = sample.get_buffer().map(Gst.MapFlags.READ)
-        if exist:
-            stream = Gio.MemoryInputStream.new_from_data(mapflags.data,
-                                                         None)
-            try:
+        try:
+            infos = self.get_infos(filepath)
+            exist = False
+            if infos is not None:
+                (exist, sample) = infos.get_tags().get_sample_index('image', 0)
+            if exist:
+                (exist, mapflags) = sample.get_buffer().map(Gst.MapFlags.READ)
+            if exist:
+                stream = Gio.MemoryInputStream.new_from_data(mapflags.data,
+                                                             None)
                 pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(stream,
                                                                    size,
                                                                    size,
                                                                    False,
                                                                    None)
-            except:
-                pass
+        except:
+            pass
         return pixbuf
 
 #######################
 # PRIVATE             #
 #######################
-    def _get_album_cache_name(self, album, sql=None):
+    def _get_album_cache_name(self, album):
         """
             Get a uniq string for album
             @param album as Album
-            @param sql as sqlite cursor
         """
         path = album.name + "_" + album.artist_name
         return path[0:240].replace("/", "_")
