@@ -217,6 +217,17 @@ class Container:
         if view:
             view.update_children()
 
+    def reload_view(self):
+        """
+            Reload current view
+        """
+        if self._list_two.is_visible():
+            value = self._list_two.get_selected_id()
+            self._list_two.select_id(value)
+        else:
+            value = self._list_one.get_selected_id()
+            self._list_one.select_id(value)
+
     def pulse(self, pulse):
         """
             Make progress bar visible/pulse if pulse is True
@@ -280,8 +291,6 @@ class Container:
         vgrid.add(self._progress)
         vgrid.show()
 
-        separator = Gtk.Separator()
-        separator.show()
         self._paned_list_view.add1(self._list_two)
         self._paned_list_view.add2(vgrid)
         self._paned_main_list.add1(self._list_one)
