@@ -29,6 +29,7 @@ class QueueWidget(Gtk.Popover):
             Init Popover
         """
         Gtk.Popover.__init__(self)
+        self.set_position(Gtk.PositionType.BOTTOM)
         self.connect('map', self._on_map)
         self.connect('unmap', self._on_unmap)
         self._timeout = None
@@ -74,11 +75,16 @@ class QueueWidget(Gtk.Popover):
 
         self.add(self._widget)
 
+    def do_show(self):
+        """
+            Set widget size
+        """
         size_setting = Lp().settings.get_value('window-size')
         if isinstance(size_setting[1], int):
-            self.set_size_request(420, size_setting[1]*0.7)
+            self.set_size_request(400, size_setting[1]*0.7)
         else:
-            self.set_size_request(420, 600)
+            self.set_size_request(400, 600)
+        Gtk.Popover.do_show(self)
 
     def populate(self):
         """
