@@ -44,9 +44,9 @@ class Toolbar(Gtk.HeaderBar):
         self.set_custom_title(self._toolbar_title)
         self.pack_end(self._toolbar_end)
 
-        Lp.player.connect('status-changed', self._on_status_changed)
-        Lp.player.connect('current-changed', self._on_current_changed)
-        Lp.player.connect('next-changed', self._on_next_changed)
+        Lp().player.connect('status-changed', self._on_status_changed)
+        Lp().player.connect('current-changed', self._on_current_changed)
+        Lp().player.connect('next-changed', self._on_next_changed)
 
     def do_get_preferred_height(self):
         """
@@ -65,7 +65,7 @@ class Toolbar(Gtk.HeaderBar):
             Update progress bar position
             @param value as int
         """
-        self._toolbar_title.update_position(value)
+        self._toolbar_title._update_position(value)
 
     def set_progress_width(self, width):
         """
