@@ -10,10 +10,9 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib, Gdk, Gst
+from gi.repository import Gtk, GLib, Gst
 
 from lollypop.define import Lp, Type
-from lollypop.pop_slider import SliderPopover
 from lollypop.utils import seconds_to_string
 
 
@@ -40,9 +39,6 @@ class ToolbarTitle(Gtk.Bin):
         self._progress = builder.get_object('progress_scale')
         self._progress.set_sensitive(False)
 
-        self._popover = SliderPopover()
-        self._popover.set_relative_to(self._progress)
-
         self._timelabel = builder.get_object('playback')
         self._total_time_label = builder.get_object('duration')
 
@@ -53,19 +49,6 @@ class ToolbarTitle(Gtk.Bin):
         """
         self._progress.set_property("width_request", width)
 
-    def update_position(self, value=None):
-        """
-            Update progress bar position
-            @param value as int
-        """
-        if not self._seeking:
-            if value is None and Lp.player.get_status() != Gst.State.PAUSED:
-                value = Lp.player.get_position_in_track()/1000000
-            if value is not None:
-                self._progress.set_value(value)
-                self._timelabel.set_text(seconds_to_string(value/60))
-        return True
-
     def on_current_changed(self, player):
         """
             Update scale on current changed
@@ -99,10 +82,10 @@ class ToolbarTitle(Gtk.Bin):
                 GLib.source_remove(self._timeout)
                 self._timeout = None
             elif not self._timeout:
-                self._timeout = GLib.timeout_add(1000, self.update_position)
+                self._timeout = GLib.timeout_add(1000, self._update_position)
         else:
             self.set_opacity(0.5)
-            self.update_position()
+            self._update_position()
             if self._timeout:
                 GLib.source_remove(self._timeout)
                 self._timeout = None
@@ -110,41 +93,18 @@ class ToolbarTitle(Gtk.Bin):
 #######################
 # PRIVATE             #
 #######################
-    def _on_progress_motion_notify(self, eventbox, event):
+    def _update_position(self, value=None):
         """
-            Show progress popover
-            @param eventbox as Gtk.EventBox
-            @param event as Gdk.Event
+            Update progress bar position
+            @param value as int
         """
-        if Gtk.get_minor_version() > 14:
-            slider_width = self._progress.style_get_property(
-                                                            'slider-width') / 2
-        else:
-            slider_width = 14
-        rect = self._progress.get_range_rect()
-        if event.x < slider_width or\
-           event.x > rect.width - slider_width:
-            return
-
-        current = (event.x - slider_width) *\
-            self._progress.get_adjustment().get_upper() /\
-            (rect.width - slider_width * 2)
-        self._popover.set(seconds_to_string(current/60))
-        r = Gdk.Rectangle()
-        r.x = event.x
-        r.y = rect.height
-        r.width = 1
-        r.height = 1
-        self._popover.set_pointing_to(r)
-        self._popover.show()
-
-    def _on_progress_leave_notify(self, eventbox, event):
-        """
-            Show progress popover
-            @param eventbox as Gtk.EventBox
-            @param event as Gdk.Event
-        """
-        self._popover.delayed_hide()
+        if not self._seeking:
+            if value is None and Lp().player.get_status() != Gst.State.PAUSED:
+                value = Lp().player.get_position_in_track()/1000000
+            if value is not None:
+                self._progress.set_value(value)
+                self._timelabel.set_text(seconds_to_string(value/60))
+        return True
 
     def _on_progress_press_button(self, scale, event):
         """
@@ -162,6 +122,26 @@ class ToolbarTitle(Gtk.Bin):
             @param event as Gdk.Event
         """
         value = scale.get_value()
-        Lp.player.seek(value/60)
+        Lp().player.seek(value/60)
         self._seeking = False
-        self.update_position(value)
+        self._update_position(value)
+
+    def _on_scroll_event(self, scale, event):
+        """
+            Seek forward or backward
+            @param scale as Gtk.Scale
+            @param event as Gdk.Event
+        """
+        (smooth, x, y) = event.get_scroll_deltas()
+        if smooth and Lp().player.is_playing():
+            position = Lp().player.get_position_in_track()
+            if y > 0:
+                seek = position/1000000/60-5
+            else:
+                seek = position/1000000/60+5
+            if seek < 0:
+                seek = 0
+            if seek > Lp().player.current_track.duration:
+                seek = Lp().player.current_track.duration - 2
+            Lp().player.seek(seek)
+            self._update_position(seek*60)
