@@ -28,12 +28,12 @@ class View(Gtk.Grid):
         self.connect('destroy', self._on_destroy)
         self.set_property('orientation', Gtk.Orientation.VERTICAL)
         self.set_border_width(0)
-        self._current_signal = Lp.player.connect('current-changed',
-                                                 self._on_current_changed)
-        self._cover_signal = Lp.art.connect('album-artwork-changed',
-                                            self._on_cover_changed)
-        self._scan_signal = Lp.scanner.connect('album-modified',
-                                               self._on_album_modified)
+        self._current_signal = Lp().player.connect('current-changed',
+                                                   self._on_current_changed)
+        self._cover_signal = Lp().art.connect('album-artwork-changed',
+                                              self._on_cover_changed)
+        self._scan_signal = Lp().scanner.connect('album-modified',
+                                                 self._on_album_modified)
 
         # Stop populate thread
         self._stop = False
@@ -53,11 +53,11 @@ class View(Gtk.Grid):
         for child in self._get_children():
             child.stop()
 
-    def update_covers(self):
+    def update_children(self):
         """
-            Update children's covers
+            Update children
         """
-        GLib.idle_add(self._update_widgets, self._get_children(), True)
+        GLib.idle_add(self._update_widgets, self._get_children())
 
     def populate(self):
         pass
@@ -65,18 +65,17 @@ class View(Gtk.Grid):
 #######################
 # PRIVATE             #
 #######################
-    def _update_widgets(self, widgets, force):
+    def _update_widgets(self, widgets):
         """
             Update all widgets
             @param widgets as AlbumWidget
-            @param force as bool
         """
         if widgets:
             widget = widgets.pop(0)
             widget.update_state()
             widget.update_cursor()
             widget.update_playing_indicator()
-            GLib.idle_add(self._update_widgets, widgets, force)
+            GLib.idle_add(self._update_widgets, widgets)
 
     def _get_children(self):
         """
@@ -90,13 +89,13 @@ class View(Gtk.Grid):
             @param widget as Gtk.Widget
         """
         if self._current_signal:
-            Lp.player.disconnect(self._current_signal)
+            Lp().player.disconnect(self._current_signal)
             self._current_signal = None
         if self._cover_signal:
-            Lp.art.disconnect(self._cover_signal)
+            Lp().art.disconnect(self._cover_signal)
             self._cover_signal = None
         if self._scan_signal:
-            Lp.scanner.disconnect(self._scan_signal)
+            Lp().scanner.disconnect(self._scan_signal)
             self._scan_signal = None
 
     def _on_cover_changed(self, widget, album_id):
@@ -112,7 +111,7 @@ class View(Gtk.Grid):
             Current song changed
             @param player as Player
         """
-        GLib.idle_add(self._update_widgets, self._get_children(), False)
+        GLib.idle_add(self._update_widgets, self._get_children())
 
     def _on_album_modified(self, scanner, album_id):
         """
